@@ -140,8 +140,8 @@ class DiagramMetrics(object):
     span_width = cellsize * 8
     span_height = cellsize * 5
 
-    def __init__(self, diagram, **kwargs):
-        self.drawer = kwargs.get('drawer')
+    def __init__(self, diagram, drawer=None, fontmap=None):
+        self.drawer = drawer
 
         if diagram.node_width is not None:
             self.node_width = diagram.node_width
@@ -155,7 +155,6 @@ class DiagramMetrics(object):
         if diagram.span_height is not None:
             self.span_height = diagram.span_height
 
-        fontmap = kwargs.get('fontmap')
         if fontmap is not None:
             self.fontmap = fontmap
         else:
@@ -350,8 +349,8 @@ class SpreadSheetMetrics(SubMetrics):
         x, y = self._node_bottomright(dummy, use_padding=False)
         x_span = self.span_width[width]
         y_span = self.span_height[height]
-        return XY(x + margin.x + padding[1] + x_span,
-                  y + margin.y + padding[2] + y_span)
+        return Size(x + margin.x + padding[1] + x_span,
+                    y + margin.y + padding[2] + y_span)
 
 
 class NodeMetrics(SubMetrics):
