@@ -13,8 +13,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from blockdiag.noderenderer import NodeShape
 from blockdiag.noderenderer import install_renderer
+from blockdiag.noderenderer.base import NodeShape
 
 
 class Box(NodeShape):
