@@ -20,7 +20,7 @@ from blockdiag import plugins
 class AutoClass(plugins.NodeHandler):
     def on_created(self, node):
         if node.id is None:
-            return
+            return True
 
         for name, klass in self.diagram.classes.items():
             pattern = "_%s$" % re.escape(name)
@@ -29,6 +29,8 @@ class AutoClass(plugins.NodeHandler):
                 node.label = re.sub(pattern, '', node.id)
                 node.set_attributes(klass.attrs)
 
+        return True
+
 
 def setup(self, diagram, **kwargs):
     plugins.install_node_handler(AutoClass(diagram, **kwargs))
