@@ -20,6 +20,7 @@ import traceback
 from optparse import OptionParser, SUPPRESS_HELP
 from blockdiag import imagedraw
 from blockdiag import plugins
+from blockdiag.utils import images
 from blockdiag.utils.compat import codecs
 from blockdiag.utils.config import ConfigParser
 from blockdiag.utils.fontmap import parse_fontpath, FontMap
@@ -30,10 +31,24 @@ class Application(object):
     module = None
     options = None
 
+    def __init__(self):
+        self.cleanup_handlers = []
+
+    def __enter__(self):
+        self.setup()
+        return self
+
+    def __exit__(self, *args):
+        self.cleanup()
+
+    def register_cleanup_handler(self, handler):
+        self.cleanup_handlers.append(handler)
+
     def run(self, args):
         try:
             self.parse_options(args)
             self.create_fontmap()
+            self.setup()
 
             parsed = self.parse_diagram()
             return self.build_diagram(parsed)
@@ -49,8 +64,7 @@ class Application(object):
                 error("%s" % e)
             return -1
         finally:
-            plugins.fire_general_event('cleanup')
-            plugins.unload_all()
+            self.cleanup()
 
     def parse_options(self, args):
         self.options = Options(self.module).parse(args)
@@ -58,6 +72,10 @@ class Application(object):
     def create_fontmap(self):
         self.fontmap = create_fontmap(self.options)
 
+    def setup(self):
+        images.setup(self)
+        plugins.setup(self)
+
     def parse_diagram(self):
         if self.options.input == '-':
             stream = codecs.getreader('utf-8-sig')(sys.stdin)
@@ -90,6 +108,15 @@ class Application(object):
 
         return 0
 
+    def cleanup(self):
+        for handler in self.cleanup_handlers[:]:
+            try:
+                handler()
+            except Exception as exc:
+                error("%s" % exc)
+            finally:
+                self.cleanup_handlers.remove(handler)
+
 
 class Options(object):
     def __init__(self, module):
